(function ($) {
  Drupal.behaviors.improvements = {
    attach: function (context, settings) {
      // Text format confirmation
      $('.filter-wrapper .filter-list', context).each(function () {
        var $select = $(this);

        if ($select.data('value')) {
          return;
        }

        $select.data('value', this.value);

        $select.change(function () {
          var oldValue = $select.data('value');
          if (oldValue == 'raw_html' && oldValue != this.value) {
            if (!confirm('Смена формата может привести к потере форматирования и изменению html кода. Вы действительно хотите сменить формат?')) {
              this.value = oldValue;
            }
          }
          $select.data('value', this.value);
        });
      });

      // Tab indent
      $('.text-format-wrapper .form-textarea', context).once('tab-indent').keydown(function (e) {
        if(e.keyCode === 9) {
          var textarea = this;
          var selectionStart = textarea.selectionStart;
          var selectionEnd = textarea.selectionEnd;

          textarea.value = textarea.value.substring(0, selectionStart) + "\t" + textarea.value.substring(selectionEnd);
          textarea.selectionStart = textarea.selectionEnd = selectionStart + 1;
          e.preventDefault();
        }
      });

      // Fix reCaptcha on AJAX forms
      if ('grecaptcha' in window && context !== document) {
        $('.g-recaptcha:empty', context).each(function () {
          grecaptcha.render(this, $(this).data());
        });
      }

      // Create new event on textfields
      $('input[type="text"]', context).each(function () {
        var $input = $(this);

        if (!$(this).data('newChangeEventProcessed')) {
          var timer;

          $input.keyup(function (event) {
            clearTimeout(timer);
            timer = setTimeout(function () {
              if ($input.is(':focus')) {
                $input.change();
              }
            }, 600);
          });

          $input.data('newChangeEventProcessed', true);
        }
      });
    }
  };

  if (Drupal.ajax) {
    var ajaxBeforeSend = Drupal.ajax.prototype.beforeSend;
    var ajaxSuccess = Drupal.ajax.prototype.success;
    var ajaxError = Drupal.ajax.prototype.error;
    var defaultClass = 'ajax-loading';

    Drupal.ajax.prototype.beforeSend = function(xmlhttprequest, options) {
      var elementFocused = $(this.element).is(':focus');

      ajaxBeforeSend.apply(this, arguments);

      // Add new progress type
      if (this.progress.type == 'class') {
        this.progress.targetElement = $(this.progress.target);
        this.progress.targetElement.addClass(this.progress.class ? this.progress.class : defaultClass);
      }

      // New ajax option - forbids to add "disabled" attribute in element
      if ('disabled' in this && !this.disabled) {
        this.ajaxing = false;
        $(this.element).removeClass('progress-disabled').attr('disabled', false);

        // Restore focus
        if (elementFocused) {
          $(this.element).focus();
        }
      }
    };

    Drupal.ajax.prototype.success = function(response, status) {
      ajaxSuccess.apply(this, arguments);

      // Add new progress type
      if (this.progress.type == 'class') {
        this.progress.targetElement.removeClass(this.progress.class ? this.progress.class : defaultClass);
      }
    };

    Drupal.ajax.prototype.error = function(xmlhttprequest, uri, customMessage) {
      ajaxError.apply(this, arguments);

      // Add new progress type
      if (this.progress.type == 'class') {
        this.progress.targetElement.removeClass(this.progress.class ? this.progress.class : defaultClass);
      }
    };

    /**
     * Animated scroll to element.
     */
    Drupal.ajax.prototype.commands.scrollTo = function(ajax, response, status) {
      var $element = $(response.selector);
      var elementOffsetTop = Math.round($element.offset().top);
      var $fixedElement = response.fixedElementSelector ? $(response.fixedElementSelector) : null;
      var fixedElementHeight = ($fixedElement && $fixedElement.css('position') == 'fixed') ? $fixedElement.height() + 0 : 0;
      var windowScrollTop = $(window).scrollTop();

      if (windowScrollTop + fixedElementHeight > elementOffsetTop) {
        var newWindowScrollTop = elementOffsetTop - fixedElementHeight;
        var animationSpeed = response.speed ? response.speed : 300;

        $('html, body').animate({
          scrollTop: newWindowScrollTop
        }, animationSpeed);
      }
    }
  }
})(jQuery);
